@@ -26,6 +26,8 @@ function createEnvironmentDiv(key, description, path, checked = false) {
   input.setAttribute('title', title);
   input.setAttribute('name', 'environment_path');
   input.setAttribute('value', path);
+
+  input.addEventListener('change', updateEnvironmentAddPathRequired);
   if (checked) {
     input.setAttribute('checked', '');
   }
@@ -256,17 +258,26 @@ function setVisible(element, visible) {
   }
 }
 
+function updateEnvironmentAddPathRequired() {
+  const environmentAddRadio = document.getElementById('environment_add_radio');
+  const environmentAddPath = document.getElementById('environment_add_path');
+  if (environmentAddRadio.checked) {
+    environmentAddPath.setAttribute('required', '');
+  } else {
+    environmentAddPath.removeAttribute('required');
+  }
+}
+
 function setSimplePartition(name) {
   const partitionElem = document.getElementById('partition');
   const gpuDivSimple = document.getElementById('gpu_simple');
   const gpuRadio0Simple = document.getElementById('0Gpu');
   const ngpusElem = document.getElementById('ngpus');
-  const quarterCpuFieldSimple = document.getElementById('quarterCpufield');
+  const fourCoreSimple = document.getElementById('fourCores');
   const quarterCoreSimple = document.getElementById('quarterCore');
-  const halfCpuFieldSimple = document.getElementById('halfCpufield');
-  const halfCoreSimple = document.getElementById('halfCore');
-  const maximumCpuFieldSimple = document.getElementById('maximumCpufield');
-  const maximumCoreSimple = document.getElementById('maximumCore');
+  const quarterCoresLabel = document.querySelector(
+    `label[for="${quarterCoreSimple.id}"]`
+  );
   const nprocsElem = document.getElementById('nprocs');
   const runtimeSelect = document.getElementById('runtime_simple');
 
@@ -285,16 +296,16 @@ function setSimplePartition(name) {
 
   // Update displayed NProcs info and values
   // Get number of CPUs for given paritition choice
-  const maxNProcs = info.max_nprocs;
-  const quarterNProcs = Math.floor(maxNProcs / 4);
-  const halfNProcs = Math.floor(maxNProcs / 2);
+  const quarterNProcs = Math.floor(info.max_nprocs / 4);
 
-  quarterCpuFieldSimple.textContent = `${quarterNProcs} cores`;
+  quarterCoresLabel.textContent = `${quarterNProcs} cores`;
   quarterCoreSimple.value = quarterNProcs;
-  halfCpuFieldSimple.textContent = `${halfNProcs} cores`;
-  halfCoreSimple.value = halfNProcs;
-  maximumCpuFieldSimple.textContent = `${maxNProcs} cores`;
-  maximumCoreSimple.value = maxNProcs;
+  const quarterCoreIsVisible = quarterNProcs > 4;
+  setVisible(quarterCoresLabel, quarterCoreIsVisible);
+  if (quarterCoreSimple.checked && !quarterCoreIsVisible) {
+    fourCoreSimple.checked = true;
+    fourCoreSimple.dispatchEvent(new Event('change'));
+  }
 
   // Update nprocs according to current CPUs choice
   const selector = document.querySelector(
@@ -369,7 +380,7 @@ function storeConfigToLocalStorage() {
     'mem_input',
     'ngpus',
     'runtime',
-    'jupyterlab',
+    'default_url',
     'output',
     'reservation',
     'options',
@@ -445,7 +456,7 @@ function restoreConfigFromLocalStorage() {
     }
     runtimeSelect.value = config['simple']['runtime'];
     runtimeSelect.dispatchEvent(new Event('change'));
-    jupyterlabSimpleElem.checked = config['fields']['jupyterlab'];
+    jupyterlabSimpleElem.checked = config['fields']['default_url'];
     jupyterlabSimpleElem.dispatchEvent(new Event('change'));
   }
 
@@ -458,8 +469,8 @@ document.addEventListener('DOMContentLoaded', () => {
 
   const nprocsElem = document.getElementById('nprocs');
   const ngpusElem = document.getElementById('ngpus');
-  const jupyterlabElem = document.getElementById('jupyterlab');
   const runtimeElem = document.getElementById('runtime');
+  const default_url = document.getElementById('default_url');
   const environmentAddRadio = document.getElementById('environment_add_radio');
   const environmentAddName = document.getElementById('environment_add_name');
   const environmentAddPath = document.getElementById('environment_add_path');
@@ -490,11 +501,11 @@ document.addEventListener('DOMContentLoaded', () => {
       ngpusElem.value = e.target.value;
     });
   });
-  // JupyterLab
+  // JupyterLab using default_url field
   document
     .getElementById('jupyterlab_simple')
     .addEventListener('change', (e) => {
-      jupyterlabElem.checked = e.target.checked;
+      default_url.checked = e.target.checked;
     });
   // Runtime
   document.getElementById('runtime_simple').addEventListener('change', (e) => {
@@ -536,23 +547,19 @@ document.addEventListener('DOMContentLoaded', () => {
     .getElementById('environment_add_path')
     .addEventListener('input', (e) => {
       const isInputEmpty = e.target.value === '';
-      if (
-        !environmentAddRadio.disabled &&
-        isInputEmpty &&
-        environmentAddRadio.checked
-      ) {
-        // Path just cleared while its radio button was selected
-        resetEnvironmentSelection();
-      }
-      if (environmentAddRadio.disabled && !isInputEmpty) {
+      if (environmentAddRadio.value === '' && !isInputEmpty) {
         // First input in the path: select its radio button
         environmentAddRadio.checked = true;
       }
       environmentAddRadio.value = e.target.value;
-      environmentAddRadio.disabled = isInputEmpty;
       environmentAddButton.disabled = isInputEmpty;
     });
 
+  environmentAddRadio.addEventListener(
+    'change',
+    updateEnvironmentAddPathRequired
+  );
+
   environmentAddButton.addEventListener('click', (e) => {
     const key = `custom-${Date.now()}`; // Poor man's UUID
     addCustomEnvironment(
@@ -562,6 +569,7 @@ document.addEventListener('DOMContentLoaded', () => {
     );
     if (environmentAddRadio.checked) {
       selectEnvironment(key);
+      updateEnvironmentAddPathRequired();
     }
     environmentAddName.value = '';
     environmentAddPath.value = '';
